@@ -41,9 +41,10 @@ class OssTemporaryPermissions:
         return Sts20150401Client(config)
 
     def get_security_token(self):
-        num = 0
-        while num >= 2:
+        retry_count = 0
+        while True:
             try:
+                retry_count += 1
                 client = self.create_client()
                 assume_role_request = sts_20150401_models.AssumeRoleRequest()
                 assume_role_request.duration_seconds = self.duration_seconds
@@ -52,10 +53,9 @@ class OssTemporaryPermissions:
                 resp = client.assume_role(assume_role_request)
                 return UtilClient.to_jsonstring(TeaCore.to_map(resp))
             except Exception as e:
-                logger.error(e)
-                num += 1
-        else:
-            raise Exception("oss_temporary_permissions has error")
+                if retry_count >= 3:
+                    logger.error(e)
+                    raise Exception("oss_temporary_permissions has error")
 
 
 if __name__ == '__main__':
@@ -68,6 +68,7 @@ if __name__ == '__main__':
         3600
     )
     aa = tok.get_security_token()
+    print(aa)
     # '''
     #     oss_temporary_permissions.endpoint = sts.cn-shenzhen.aliyuncs.com
     #     oss_temporary_permissions.access_key_id = LTAI5t7p1eu71D42w6rQgRVe
